window.Gleam.initSearch([{"doc":"morse_code_translator","title":"morse_code_translator","content":"# Morse Code Translator\n\n[![Package Version](https://img.shields.io/hexpm/v/morse_code_translator)](https://hex.pm/packages/morse_code_translator)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/morse_code_translator/)\n\n## Links\n\n* [Web tool](https://salif.github.io/morse-code-translator/)\n* [Source code](https://codeberg.org/salif/morse-code-translator)\n* [Discussions (Github)](https://github.com/salif/morse-code-translator/discussions)\n\n## Gleam library\n\n### Installation\n\n```sh\ngleam add morse_code_translator@2\n```\n\n### Usage\n\n```gleam\nimport gleam/io\nimport gleam/option.{None, Some}\nimport gleam/result\nimport morse_code_translator as mct\n\npub fn main() {\n   let demo_encode_options =\n      mct.EncodeOptions(\n         output_dot: None,\n         output_dash: None,\n         output_space: None,\n         output_separator: None,\n         is_uppercase: None,\n         language: None,\n      )\n\n   let demo_decode_options =\n      mct.DecodeOptions(\n         input_dot: None,\n         input_dash: None,\n         input_space: None,\n         input_separator: None,\n         to_uppercase: None,\n         language: None,\n      )\n\n   &quot; Test &quot;\n   |&gt; mct.encode(demo_encode_options, None)\n   |&gt; result.map(io.println)\n   // &quot;/ - . ... - /&quot;\n\n   &quot;/ - . ... - /&quot;\n   |&gt; mct.decode(demo_decode_options, None)\n   |&gt; result.map(io.println)\n   // &quot; test &quot;\n\n   &quot;demo&quot;\n   |&gt; mct.encode_to_string(demo_encode_options, None)\n   |&gt; mct.decode_to_string(demo_decode_options, None)\n   |&gt; io.println\n   // &quot;demo&quot;\n\n   &quot;_.. . __ ___&quot;\n   |&gt; mct.decode_to_string(\n      mct.DecodeOptions(\n         ..demo_decode_options,\n         input_dash: Some(&quot;_&quot;),\n         language: Some(mct.language_cyrillic),\n      ),\n      None,\n   )\n   |&gt; io.println\n   // &quot;демо&quot;\n\n   let demo_convert_options =\n      mct.ConvertOptions(\n         input_dot: mct.default_dot,\n         output_dot: &quot;0&quot;,\n         input_dash: mct.default_dash,\n         output_dash: &quot;1&quot;,\n         input_space: mct.default_space,\n         output_space: mct.default_space,\n         input_separator: mct.default_separator,\n         output_separator: mct.default_separator,\n      )\n\n   &quot;-.. . -- ---&quot;\n   |&gt; mct.convert(demo_convert_options)\n   |&gt; result.map(io.println)\n   // &quot;100 0 11 111&quot;\n\n   &quot;=&quot;\n   |&gt; mct.convert_to_string(demo_convert_options)\n   |&gt; io.println\n   // &quot;Invalid morse code symbol: =&quot;\n}\n```\n\n### Version 2.2.0\n\nVersion `2.2.0` contains backward incompatible changes.\nIf you are using `EncodeOptions` and `DecodeOptions`, change `language_num` to `language`.\n\nFurther documentation can be found at &lt;https://hexdocs.pm/morse_code_translator&gt;.\n\n## Web tool\n\n### Add new page language\n\nOpen `index.html` and find all occurrences of `set_page_language`, `data-lo=` \nand `dataset.lo =`, then add translations and send a pull request.\n\n### Manually set page language\n\nUse &lt;a href=&quot;javascript:(function(){window.set_page_language(window.prompt(&#39;Enter language code&#39;)??&#39;&#39;);})()&quot;&gt;this bookmarklet&lt;/a&gt;, save it as bookmark, then open it at the web page.\n\n\n## Development\n\n```sh\n# just format\njust build\njust serve\n```\n","url":"index.html"},{"doc":"characters","title":"base_characters","content":"pub const base_characters: List(#(String, String, List(Bool)))\n\nSynonyms:\ncharacters.base_characters\ncharacters base_characters","url":"characters.html#base_characters"},{"doc":"characters","title":"characters","content":"","url":"characters.html"},{"doc":"morse_code_translator","title":"ConvertOptions","content":"pub type ConvertOptions {\n  ConvertOptions(\n    input_dot: String,\n    output_dot: String,\n    input_dash: String,\n    output_dash: String,\n    input_space: String,\n    output_space: String,\n    input_separator: String,\n    output_separator: String,\n  )\n}\n\nConvertOptions(\n  input_dot: String,\n  output_dot: String,\n  input_dash: String,\n  output_dash: String,\n  input_space: String,\n  output_space: String,\n  input_separator: String,\n  output_separator: String,\n)\n\n\nSynonyms:\nmorse_code_translator.ConvertOptions\nmorse_code_translator ConvertOptions","url":"morse_code_translator.html#ConvertOptions"},{"doc":"morse_code_translator","title":"DecodeOptions","content":"pub type DecodeOptions {\n  DecodeOptions(\n    input_dot: option.Option(String),\n    input_dash: option.Option(String),\n    input_space: option.Option(String),\n    input_separator: option.Option(String),\n    to_uppercase: option.Option(Bool),\n    language: option.Option(Language),\n  )\n}\n\nDecodeOptions(\n  input_dot: option.Option(String),\n  input_dash: option.Option(String),\n  input_space: option.Option(String),\n  input_separator: option.Option(String),\n  to_uppercase: option.Option(Bool),\n  language: option.Option(Language),\n)\n\n\nSynonyms:\nmorse_code_translator.DecodeOptions\nmorse_code_translator DecodeOptions","url":"morse_code_translator.html#DecodeOptions"},{"doc":"morse_code_translator","title":"EncodeOptions","content":"pub type EncodeOptions {\n  EncodeOptions(\n    output_dot: option.Option(String),\n    output_dash: option.Option(String),\n    output_space: option.Option(String),\n    output_separator: option.Option(String),\n    is_uppercase: option.Option(Bool),\n    language: option.Option(Language),\n  )\n}\n\nEncodeOptions(\n  output_dot: option.Option(String),\n  output_dash: option.Option(String),\n  output_space: option.Option(String),\n  output_separator: option.Option(String),\n  is_uppercase: option.Option(Bool),\n  language: option.Option(Language),\n)\n\n\nSynonyms:\nmorse_code_translator.EncodeOptions\nmorse_code_translator EncodeOptions","url":"morse_code_translator.html#EncodeOptions"},{"doc":"morse_code_translator","title":"Language","content":"pub type Language {\n  Language(num: String)\n}\n\nLanguage(num: String)\n\n\nSynonyms:\nmorse_code_translator.Language\nmorse_code_translator Language","url":"morse_code_translator.html#Language"},{"doc":"morse_code_translator","title":"MorseCodeError","content":"pub type MorseCodeError {\n  MorseCodeError(msg: String)\n}\n\nMorseCodeError(msg: String)\n\n\nSynonyms:\nmorse_code_translator.MorseCodeError\nmorse_code_translator MorseCodeError","url":"morse_code_translator.html#MorseCodeError"},{"doc":"morse_code_translator","title":"MorseCodeList","content":"pub type MorseCodeList =\n  List(#(String, String, List(Bool)))\n\n\nSynonyms:\nmorse_code_translator.MorseCodeList\nmorse_code_translator MorseCodeList","url":"morse_code_translator.html#MorseCodeList"},{"doc":"morse_code_translator","title":"default_dash","content":"pub const default_dash: String\n\nSynonyms:\nmorse_code_translator.default_dash\nmorse_code_translator default_dash","url":"morse_code_translator.html#default_dash"},{"doc":"morse_code_translator","title":"default_dot","content":"pub const default_dot: String\n\nSynonyms:\nmorse_code_translator.default_dot\nmorse_code_translator default_dot","url":"morse_code_translator.html#default_dot"},{"doc":"morse_code_translator","title":"default_is_uppercase","content":"pub const default_is_uppercase: Bool\n Input will be converted to uppercase\nSynonyms:\nmorse_code_translator.default_is_uppercase\nmorse_code_translator default_is_uppercase","url":"morse_code_translator.html#default_is_uppercase"},{"doc":"morse_code_translator","title":"default_language","content":"pub const default_language: Language\n Default language is ASCII\nSynonyms:\nmorse_code_translator.default_language\nmorse_code_translator default_language","url":"morse_code_translator.html#default_language"},{"doc":"morse_code_translator","title":"default_separator","content":"pub const default_separator: String\n\nSynonyms:\nmorse_code_translator.default_separator\nmorse_code_translator default_separator","url":"morse_code_translator.html#default_separator"},{"doc":"morse_code_translator","title":"default_space","content":"pub const default_space: String\n\nSynonyms:\nmorse_code_translator.default_space\nmorse_code_translator default_space","url":"morse_code_translator.html#default_space"},{"doc":"morse_code_translator","title":"default_to_uppercase","content":"pub const default_to_uppercase: Bool\n Output will be converted to lowercase\nSynonyms:\nmorse_code_translator.default_to_uppercase\nmorse_code_translator default_to_uppercase","url":"morse_code_translator.html#default_to_uppercase"},{"doc":"morse_code_translator","title":"language_arabic","content":"pub const language_arabic: Language\n Arabic\nSynonyms:\nmorse_code_translator.language_arabic\nmorse_code_translator language_arabic","url":"morse_code_translator.html#language_arabic"},{"doc":"morse_code_translator","title":"language_cyrillic","content":"pub const language_cyrillic: Language\n Cyrillic languages\nSynonyms:\nmorse_code_translator.language_cyrillic\nmorse_code_translator language_cyrillic","url":"morse_code_translator.html#language_cyrillic"},{"doc":"morse_code_translator","title":"language_greek","content":"pub const language_greek: Language\n Greek\nSynonyms:\nmorse_code_translator.language_greek\nmorse_code_translator language_greek","url":"morse_code_translator.html#language_greek"},{"doc":"morse_code_translator","title":"language_hebrew","content":"pub const language_hebrew: Language\n Hebrew\nSynonyms:\nmorse_code_translator.language_hebrew\nmorse_code_translator language_hebrew","url":"morse_code_translator.html#language_hebrew"},{"doc":"morse_code_translator","title":"language_japanese","content":"pub const language_japanese: Language\n Japanese\nSynonyms:\nmorse_code_translator.language_japanese\nmorse_code_translator language_japanese","url":"morse_code_translator.html#language_japanese"},{"doc":"morse_code_translator","title":"language_korean","content":"pub const language_korean: Language\n Korean\nSynonyms:\nmorse_code_translator.language_korean\nmorse_code_translator language_korean","url":"morse_code_translator.html#language_korean"},{"doc":"morse_code_translator","title":"language_latin","content":"pub const language_latin: Language\n ASCII\nSynonyms:\nmorse_code_translator.language_latin\nmorse_code_translator language_latin","url":"morse_code_translator.html#language_latin"},{"doc":"morse_code_translator","title":"language_latin_extended","content":"pub const language_latin_extended: Language\n Latin Extended (Turkish, Polish etc.)\nSynonyms:\nmorse_code_translator.language_latin_extended\nmorse_code_translator language_latin_extended","url":"morse_code_translator.html#language_latin_extended"},{"doc":"morse_code_translator","title":"language_numbers","content":"pub const language_numbers: Language\n Numbers\nSynonyms:\nmorse_code_translator.language_numbers\nmorse_code_translator language_numbers","url":"morse_code_translator.html#language_numbers"},{"doc":"morse_code_translator","title":"language_persian","content":"pub const language_persian: Language\n Persian\nSynonyms:\nmorse_code_translator.language_persian\nmorse_code_translator language_persian","url":"morse_code_translator.html#language_persian"},{"doc":"morse_code_translator","title":"language_punctuation","content":"pub const language_punctuation: Language\n Punctuation\nSynonyms:\nmorse_code_translator.language_punctuation\nmorse_code_translator language_punctuation","url":"morse_code_translator.html#language_punctuation"},{"doc":"morse_code_translator","title":"language_thai","content":"pub const language_thai: Language\n Thai\nSynonyms:\nmorse_code_translator.language_thai\nmorse_code_translator language_thai","url":"morse_code_translator.html#language_thai"},{"doc":"morse_code_translator","title":"morse_code_list","content":"pub const morse_code_list: List(#(String, String, List(Bool)))\n\nSynonyms:\nmorse_code_translator.morse_code_list\nmorse_code_translator morse_code_list","url":"morse_code_translator.html#morse_code_list"},{"doc":"morse_code_translator","title":"convert","content":"pub fn convert(\n  input: String,\n  options: ConvertOptions,\n) -&gt; Result(String, MorseCodeError)\n\nSynonyms:\nmorse_code_translator.convert\nmorse_code_translator convert","url":"morse_code_translator.html#convert"},{"doc":"morse_code_translator","title":"convert_to_string","content":"pub fn convert_to_string(\n  input: String,\n  options: ConvertOptions,\n) -&gt; String\n\nSynonyms:\nmorse_code_translator.convert_to_string\nmorse_code_translator convert_to_string","url":"morse_code_translator.html#convert_to_string"},{"doc":"morse_code_translator","title":"decode","content":"pub fn decode(\n  input: String,\n  options: DecodeOptions,\n  morse_code_dict: Option(List(#(String, String, List(Bool)))),\n) -&gt; Result(String, MorseCodeError)\n\nSynonyms:\nmorse_code_translator.decode\nmorse_code_translator decode","url":"morse_code_translator.html#decode"},{"doc":"morse_code_translator","title":"decode_to_string","content":"pub fn decode_to_string(\n  input: String,\n  options: DecodeOptions,\n  morse_code_dict: Option(List(#(String, String, List(Bool)))),\n) -&gt; String\n\nSynonyms:\nmorse_code_translator.decode_to_string\nmorse_code_translator decode_to_string","url":"morse_code_translator.html#decode_to_string"},{"doc":"morse_code_translator","title":"encode","content":"pub fn encode(\n  input: String,\n  options: EncodeOptions,\n  morse_code_dict: Option(List(#(String, String, List(Bool)))),\n) -&gt; Result(String, MorseCodeError)\n\nSynonyms:\nmorse_code_translator.encode\nmorse_code_translator encode","url":"morse_code_translator.html#encode"},{"doc":"morse_code_translator","title":"encode_to_string","content":"pub fn encode_to_string(\n  input: String,\n  options: EncodeOptions,\n  morse_code_dict: Option(List(#(String, String, List(Bool)))),\n) -&gt; String\n\nSynonyms:\nmorse_code_translator.encode_to_string\nmorse_code_translator encode_to_string","url":"morse_code_translator.html#encode_to_string"},{"doc":"morse_code_translator","title":"morse_code_translator","content":"","url":"morse_code_translator.html"}]);